==> fbat_1.0.0.tar.gz: fbat/R/pedFlagHomo.R <==
##FIXME: the pedFlagHomo() function should probably return an
##       object 


## get observed allele frequencies and flag homo/heterozygotes
pedFlagHomo <- function(geneSetObj, founderOnly=TRUE, quiet=FALSE)
{

  #cat("converting geneSet object to numerical matrix...\n")
  tmp<-geneSet2Ped(geneSetObj)
  ped<-tmp$ped
  columns<-tmp$columns

  res<-pedFlagHomo.default(ped, columns, founderOnly, quiet)
  invisible(res)
}

## get observed allele frequencies and flag homo/heterozygotes
pedFlagHomo.default <- function(ped,
                        columns=c("family", "pid", "father", "mother",
                                   "sex", "affected"),
                        founderOnly=TRUE, quiet=FALSE)
{
  tmp <- checkColumn(ped, columns)
  ped<-tmp$ped
  columns<-tmp$columns

  if(founderOnly==TRUE)
  { ## get parental info
    mat1 <- ped[, c(3:4)]
    tmp <- mat1[, 1]+mat1[, 2]
    pos <- which(tmp==0)
    if(length(pos)==0)
    { stop("The pedigree data contains no parental information!\n") }
 
    len <- length(columns)
    ped <- ped[pos, ] 
  }
  mat <- ped[, -c(1:len)] 

  nr <- nrow(mat)
  nc <- ncol(mat)
  nMarker <- nc/2

  mat <- as.vector(t(mat))
  mat <- as.integer(mat)
  nr <- as.integer(nr)
  nMarker <- as.integer(nMarker)

  ##if(!is.loaded(symbol.C("FlagHomo"))){ dyn.load("./GeneticsBase.so") }

  res <- .C( "FlagHomo", mat, nr, nMarker, 
            nHET=as.integer(rep(0, nMarker)), 
            nHOM=as.integer(rep(0, nMarker)), 
            nMiss1=as.integer(rep(0, nMarker)), 
            nMiss2=as.integer(rep(0, nMarker)), 
            flagHomoMat=as.integer(rep(0, nr*nMarker)),
            PACKAGE="fbat"
            )

  nHET <- res$nHET
  nHOM <- res$nHOM
  nMiss1 <- res$nMiss1 # number of genotypes containing one missing alleles 
                   ##at each marker
  nMiss2 <- res$nMiss2 # number of genotypes containing two missing alleles 
                   ##at each marker


  ## flagHomoMat[i, m]=1 if genotype i at marker m is homozygote
  ## flagHomoMat[i, m]=0 if genotype i at marker m is heterozygote
  ## flagHomoMat[i, m]=-1 if genotype i at marker m contains missing alleles
  flagHomoMat <- matrix(res$flagHomoMat, nrow=nr, byrow=T)

  ##if(is.loaded(symbol.C("FlagHomo"))){ dyn.unload("./GeneticsBase.so") }

  markerNames <- getMarkerNames(ped, columns)
  countMat <- cbind(nHOM, nHET, nMiss1, nMiss2)
  colnames(countMat) <- c("numHomo", "numHetero", "numMiss1", "numMiss2")
  rownames(countMat) <- markerNames
  colnames(flagHomoMat) <- markerNames
  cat("dim(flagHomoMat)=", dim(flagHomoMat), "\n")
  cat("length(ped[,2])=", length(ped[,2]), "\n")
  rownames(flagHomoMat) <- as.vector(ped[, 2]) # id of each individual

  if(!quiet)
  {
    cat("numHomo -- number of homozygous genotypes\n")
    cat("numHetero -- number of homozygous genotypes\n")
    cat("numMiss1 -- number of genotypes containing one missing allele\n")
    cat("numMiss2 -- number of genotypes containing two missing alleles\n")
    cat("counts>>>\n"); print(countMat);
  }

  invisible(list(countMat=countMat, flagHomoMat=flagHomoMat, 
                 markerNames=markerNames))
}




##FIXME: the pedFlagHomo() function should probably return an
##       object for which this should be the show method
#################################################################

##FreqHomo.object -- return values of the function pedFlagHomo()
viewFlagHomo <- function(flagHomo.object, markerName)
{
  if(length(markerName)!=1)
    stop("The length of 'markerName' must be one!\n")

  markerNamesVec <- flagHomo.object$markerNames
  pos <- match(markerName, markerNamesVec)
  if(is.na(pos)==TRUE)
    stop("Specified marker ", markerName, " not found\n")

  pos <- pos[1]
  countMat <- flagHomo.object$countMat
  flagHomoMat <- flagHomo.object$flagHomoMat

  labels <- rownames(flagHomoMat)
  flagHomoM <- c(flagHomoMat[, pos])
  names(flagHomoM) <- labels

  countMatM <- countMat[pos, ]
  names(countMatM) <- colnames(countMat)

  cat("flag of Homo/heterozygotes for marker ", markerName, " >>\n")
  cat("1 -- homozygous genotype\n")
  cat("0 -- heterozygous genotype\n")
  cat("-1 -- genotype containing one missing allele\n")
  cat("-2 -- genotype containing two missing allele\n")
  print(flagHomoM)

  cat("numHomo -- number of homozygous genotypes\n")
  cat("numHetero -- number of homozygous genotypes\n")
  cat("numMiss1 -- number of genotypes containing one missing allele\n")
  cat("numMiss2 -- number of genotypes containing two missing alleles\n")
  cat("counts for marker ", markerName, " >>\n"); print(countMatM);
 
  invisible(list(countMatM=countMatM, flagHomoM=flagHomoM))
}

==> fbat_1.10.0.tar.gz: fbat/R/pedFlagHomo.R <==
##FIXME: the pedFlagHomo() function should probably return an
##       object 


## get observed allele frequencies and flag homo/heterozygotes
pedFlagHomo <- function(geneSetObj, founderOnly=TRUE, quiet=FALSE)
{

  if(!quiet)
    cat("converting geneSet object to numerical matrix...\n")

  pedObj<-geneSet2Ped(geneSetObj)

  if(!quiet)
    cat("flag homozygotes and heterozygotes...\n")

  res<-pedFlagHomo.default(pedObj, founderOnly, quiet)
  invisible(res)
}

## get observed allele frequencies and flag homo/heterozygotes
pedFlagHomo.default <- function(pedObj,
                        founderOnly=TRUE, quiet=FALSE)
{
  pedObj <- checkColumn(pedObj)
  ped<-pedObj$ped
  columns<-pedObj$columns
  markerNames<-pedObj$markerNames
  nMarkers<-length(markerNames)
  len<-length(columns)

  if(founderOnly==TRUE)
  { ## get parental info
    pedObj.f<-getFounders(pedObj)
    ped<-pedObj.f$ped
  } 
  mat <- ped[, -c(1:len), drop=FALSE] 

  nr <- nrow(mat)
  nc <- ncol(mat)

  mat <- as.vector(t(mat))
  mat <- as.integer(mat)
  nr <- as.integer(nr)
  nMarkers <- as.integer(nMarkers)

  ##if(!is.loaded(symbol.C("FlagHomo"))){ dyn.load("./GeneticsBase.so") }

  res <- .C( "FlagHomo", mat, nr, nMarkers, 
            nHET=as.integer(rep(0, nMarkers)), 
            nHOM=as.integer(rep(0, nMarkers)), 
            nMiss1=as.integer(rep(0, nMarkers)), 
            nMiss2=as.integer(rep(0, nMarkers)), 
            flagHomoMat=as.integer(rep(0, nr*nMarkers)),
            PACKAGE="fbat"
            )

  nHET <- res$nHET
  nHOM <- res$nHOM
  nMiss1 <- res$nMiss1 # number of genotypes containing one missing alleles 
                   ##at each marker
  nMiss2 <- res$nMiss2 # number of genotypes containing two missing alleles 
                   ##at each marker


  ## flagHomoMat[i, m]=1 if genotype i at marker m is homozygote
  ## flagHomoMat[i, m]=0 if genotype i at marker m is heterozygote
  ## flagHomoMat[i, m]=-1 if genotype i at marker m contains missing alleles
  flagHomoMat <- matrix(res$flagHomoMat, nrow=nr, byrow=T)

  ##if(is.loaded(symbol.C("FlagHomo"))){ dyn.unload("./GeneticsBase.so") }

  markerNames <- getMarkerNames(ped, columns)
  countMat <- cbind(nHOM, nHET, nMiss1, nMiss2)
  colnames(countMat) <- c("numHomo", "numHetero", "numMiss1", "numMiss2")
  rownames(countMat) <- markerNames
  colnames(flagHomoMat) <- markerNames
  cat("dim(flagHomoMat)=", dim(flagHomoMat), "\n")
  cat("length(ped[,2])=", length(ped[,2]), "\n")
  rownames(flagHomoMat) <- as.vector(ped[, 2]) # id of each individual

  if(!quiet)
  {
    cat("numHomo -- number of homozygous genotypes\n")
    cat("numHetero -- number of homozygous genotypes\n")
    cat("numMiss1 -- number of genotypes containing one missing allele\n")
    cat("numMiss2 -- number of genotypes containing two missing alleles\n")
    cat("counts>>>\n"); print(countMat);
  }

  invisible(list(countMat=countMat, flagHomoMat=flagHomoMat, 
                 markerNames=markerNames))
}




##FIXME: the pedFlagHomo() function should probably return an
##       object for which this should be the show method
#################################################################

##FreqHomo.object -- return values of the function pedFlagHomo()
viewFlagHomo <- function(flagHomo.object, markerName)
{
  if(length(markerName)!=1)
    stop("The length of 'markerName' must be one!\n")

  markerNamesVec <- flagHomo.object$markerNames
  pos <- match(markerName, markerNamesVec)
  if(is.na(pos)==TRUE)
    stop("Specified marker ", markerName, " not found\n")

  pos <- pos[1]
  countMat <- flagHomo.object$countMat
  flagHomoMat <- flagHomo.object$flagHomoMat

  labels <- rownames(flagHomoMat)
  flagHomoM <- c(flagHomoMat[, pos])
  names(flagHomoM) <- labels

  countMatM <- countMat[pos, ]
  names(countMatM) <- colnames(countMat)

  cat("flag of Homo/heterozygotes for marker ", markerName, "\n")
  cat("1 -- homozygous genotype\n")
  cat("0 -- heterozygous genotype\n")
  cat("-1 -- genotype containing one missing allele\n")
  cat("-2 -- genotype containing two missing allele\n")
  print(flagHomoM)

  cat("numHomo -- number of homozygous genotypes\n")
  cat("numHetero -- number of homozygous genotypes\n")
  cat("numMiss1 -- number of genotypes containing one missing allele\n")
  cat("numMiss2 -- number of genotypes containing two missing alleles\n")
  cat("counts for marker ", markerName, " >>\n"); print(countMatM);
 
  invisible(list(countMatM=countMatM, flagHomoM=flagHomoM))
}
